@@ -18,7 +18,7 @@ from pygame_menu.widgets.selection import HighlightSelection, LeftArrowSelection
 from pygame_menu.widgets.widget import Button, ColorInput, DropSelect, \
     DropSelectMultiple, Frame, HMargin, Image, Label, MenuBar, MenuLink, NoneWidget, \
     ProgressBar, RangeSlider, ScrollBar, Selector, SurfaceWidget, Table, TextInput, \
-    ToggleSwitch, VMargin
+    ToggleSwitch, VFill, VMargin
 
 # Widget constants
 from pygame_menu.widgets.widget.colorinput import COLORINPUT_TYPE_RGB, \
